Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(623)

Unified Diff: runtime/observatory/tests/service/debugging_test.dart

Issue 1237203002: Insert debug step check at the beginning of a function. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/observatory/tests/service/debugging_test.dart
diff --git a/runtime/observatory/tests/service/debugging_test.dart b/runtime/observatory/tests/service/debugging_test.dart
index e20e203a763b886ce080ac3b5ba5c2d85c5f2b95..d3908b9acbfad837f1e81ae13db9206d8af40b35 100644
--- a/runtime/observatory/tests/service/debugging_test.dart
+++ b/runtime/observatory/tests/service/debugging_test.dart
@@ -187,13 +187,13 @@ var tests = [
Breakpoint bpt = result;
expect(bpt.type, equals('Breakpoint'));
expect(bpt.location.script.name, equals('debugging_test.dart'));
- expect(bpt.location.script.tokenToLine(bpt.location.tokenPos), equals(14));
+ expect(bpt.location.script.tokenToLine(bpt.location.tokenPos), equals(13));
expect(isolate.breakpoints.length, equals(1));
await completer.future; // Wait for breakpoint events.
},
// We are now at line 14.
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();
expect(stack.type, equals('Stack'));
@@ -201,7 +201,7 @@ var tests = [
Script script = stack['frames'][0].location.script;
expect(script.name,endsWith('debugging_test.dart'));
- expect(script.tokenToLine(stack['frames'][0].location.tokenPos), equals(14));
+ expect(script.tokenToLine(stack['frames'][0].location.tokenPos), equals(13));
},
];
@@ -187,13 +187,13 @@ var tests = [
await completer.future; // Wait for breakpoint events.
},
-// We are now at line 14.
+// We are now at line 13.
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();

Powered by Google App Engine
This is Rietveld 408576698